@@ -1,22 +1,9 @@
 /*
  * backgroundchecker.h
  *
- * Copyright (C)  2004  Zack Rusin <zack@kde.org>
+ * SPDX-FileCopyrightText: 2004 Zack Rusin <zack@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #ifndef SONNET_BACKGROUNDCHECKER_H
 #define SONNET_BACKGROUNDCHECKER_H
@@ -25,7 +12,7 @@
 
 #include "sonnetcore_export.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 class BackgroundCheckerPrivate;
 
 /**
@@ -77,6 +64,14 @@ public:
     QStringList suggest(const QString &word) const;
     bool addWordToPersonal(const QString &word);
 
+    /**
+     * This method is used to add a word to the session of the
+     * speller currently set in BackgroundChecker.
+     *
+     * @since 5.55
+     */
+    bool addWordToSession(const QString &word);
+
 public Q_SLOTS:
     virtual void start();
     virtual void stop();
