@@ -1,39 +1,27 @@
-/**
+/*
+ * SPDX-FileCopyrightText: 2003 Zack Rusin <zack@kde.org>
+ * SPDX-FileCopyrightText: 2012 Martin Sandsmark <martin.sandsmark@kde.org>
  *
- * Copyright (C)  2003  Zack Rusin <zack@kde.org>
- * Copyright (C)  2012  Martin Sandsmark <martin.sandsmark@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #include "loader_p.h"
 #include "settings_p.h"
 #include "client_p.h"
 #include "spellerplugin_p.h"
 
-#include <QtCore/QHash>
-#include <QtCore/QMap>
-#include <QtCore/QLocale>
-#include <QtCore/QCoreApplication>
-#include <QtCore/QPluginLoader>
+#include <QHash>
+#include <QMap>
+#include <QLocale>
+#include <QCoreApplication>
+#include <QPluginLoader>
 #include "core_debug.h"
-#include <QtCore/QDir>
+#include <QDir>
+
+#include <algorithm>
 
 #ifdef SONNET_STATIC
 #include "../plugins/hunspell/hunspellclient.h"
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 #include "../plugins/nsspellchecker/nsspellcheckerclient.h"
 #endif
 #endif
@@ -84,36 +72,52 @@ SpellerPlugin *Loader::createSpeller(const QString &language, const QString &cli
     QString backend = clientName;
     QString plang = language;
 
-    if (backend.isEmpty()) {
-        backend = d->settings->defaultClient();
-    }
     if (plang.isEmpty()) {
         plang = d->settings->defaultLanguage();
     }
 
-    const QVector<Client *> lClients = d->languageClients[plang];
-
-    if (lClients.isEmpty()) {
+    auto clientsItr = d->languageClients.constFind(plang);
+    if (clientsItr == d->languageClients.constEnd()) {
         qCWarning(SONNET_LOG_CORE) << "No language dictionaries for the language:" << plang;
+        emit loadingDictionaryFailed(plang);
         return nullptr;
     }
 
+    const QVector<Client *> lClients = *clientsItr;
+
+    if (backend.isEmpty()) {
+        backend = d->settings->defaultClient();
+        if (!backend.isEmpty()) {
+            // check if the default client supports the requested language;
+            // if it does it will be an element of lClients.
+            bool unknown = !std::any_of(lClients.constBegin(), lClients.constEnd(), [backend] (const Client *client) {
+                    return client->name() == backend; });
+            if (unknown) {
+                qCWarning(SONNET_LOG_CORE) << "Default client" << backend << "doesn't support language:" << plang;
+                backend = QString();
+            }
+        }
+    }
+
     QVectorIterator<Client *> itr(lClients);
     while (itr.hasNext()) {
         Client *item = itr.next();
         if (!backend.isEmpty()) {
             if (backend == item->name()) {
                 SpellerPlugin *dict = item->createSpeller(plang);
+                qCDebug(SONNET_LOG_CORE) << "Using the" << item->name() << "plugin for language" << plang;
                 return dict;
             }
         } else {
             //the first one is the one with the highest
             //reliability
             SpellerPlugin *dict = item->createSpeller(plang);
+            qCDebug(SONNET_LOG_CORE) << "Using the" << item->name() << "plugin for language" << plang;
             return dict;
         }
     }
 
+    qCWarning(SONNET_LOG_CORE) << "The default client" << backend << "has no language dictionaries for the language:" << plang;
     return nullptr;
 }
 
@@ -255,7 +259,7 @@ QStringList Loader::languageNames() const
     }
 
     QStringList allLocalizedDictionaries;
-    Q_FOREACH (const QString &langCode, languages()) {
+    for (const QString &langCode : languages()) {
         allLocalizedDictionaries.append(languageNameForCode(langCode));
     }
     // cache the list
@@ -271,16 +275,15 @@ Settings *Loader::settings() const
 void Loader::loadPlugins()
 {
 #ifndef SONNET_STATIC
-    const QStringList libPaths = QCoreApplication::libraryPaths() << QStringLiteral(
-        INSTALLATION_PLUGIN_PATH);
+    const QStringList libPaths = QCoreApplication::libraryPaths() << QStringLiteral(INSTALLATION_PLUGIN_PATH);
     const QLatin1String pathSuffix("/kf5/sonnet/");
     int plugins = 0;
-    Q_FOREACH (const QString &libPath, libPaths) {
+    for (const QString &libPath : libPaths) {
         QDir dir(libPath + pathSuffix);
         if (!dir.exists()) {
             continue;
         }
-        Q_FOREACH (const QString &fileName, dir.entryList(QDir::Files)) {
+        for (const QString &fileName : dir.entryList(QDir::Files)) {
             loadPlugin(dir.absoluteFilePath(fileName));
             plugins++;
         }
@@ -289,7 +292,7 @@ void Loader::loadPlugins()
         qCWarning(SONNET_LOG_CORE) << "Sonnet: No speller backends available!";
     }
 #else
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     loadPlugin(QString());
 #endif
     loadPlugin(QStringLiteral("Hunspell"));
@@ -317,7 +320,7 @@ void Loader::loadPlugin(const QString &pluginPath)
     if (pluginPath == QLatin1String("Hunspell")) {
         client = new HunspellClient(this);
     }
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     else {
         client = new NSSpellCheckerClient(this);
     }
@@ -327,7 +330,7 @@ void Loader::loadPlugin(const QString &pluginPath)
     const QStringList languages = client->languages();
     d->clients.append(client->name());
 
-    Q_FOREACH (const QString &language, languages) {
+    for (const QString &language : languages) {
         QVector<Client *> &languageClients = d->languageClients[language];
 
         if (languageClients.isEmpty()
