@@ -1,23 +1,10 @@
-/**
+/*
  * dialog.cpp
  *
- * Copyright (C)  2003  Zack Rusin <zack@kde.org>
- * Copyright (C)  2009-2010  Michel Ludwig <michel.ludwig@kdemail.net>
+ * SPDX-FileCopyrightText: 2003 Zack Rusin <zack@kde.org>
+ * SPDX-FileCopyrightText: 2009-2010 Michel Ludwig <michel.ludwig@kdemail.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #include "dialog.h"
 #include "ui_sonnetui.h"
@@ -29,25 +16,22 @@
 #include <qprogressdialog.h>
 
 #include <QDialogButtonBox>
-#include <QListView>
 #include <QStringListModel>
 #include <QPushButton>
-#include <QComboBox>
-#include <QLabel>
-#include <QtCore/QTimer>
-#include <QtWidgets/QMessageBox>
-
-namespace Sonnet
-{
+#include <QMessageBox>
 
+namespace Sonnet {
 //to initially disable sorting in the suggestions listview
 #define NONSORTINGCOLUMN 2
 
-class ReadOnlyStringListModel: public QStringListModel
+class ReadOnlyStringListModel : public QStringListModel
 {
 public:
-    ReadOnlyStringListModel(QObject *parent): QStringListModel(parent) {}
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE
+    ReadOnlyStringListModel(QObject *parent) : QStringListModel(parent)
+    {
+    }
+
+    Qt::ItemFlags flags(const QModelIndex &index) const override
     {
         Q_UNUSED(index);
         return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
@@ -91,10 +75,9 @@ public:
     }
 };
 
-Dialog::Dialog(BackgroundChecker *checker,
-               QWidget *parent)
-    : QDialog(parent),
-      d(new DialogPrivate)
+Dialog::Dialog(BackgroundChecker *checker, QWidget *parent)
+    : QDialog(parent)
+    , d(new DialogPrivate)
 {
     setModal(true);
     setWindowTitle(tr("Check Spelling", "@title:window"));
@@ -238,7 +221,10 @@ void Dialog::slotFinished()
     setProgressDialogVisible(false);
     emit stop();
     //FIXME: should we emit done here?
+#if SONNETUI_BUILD_DEPRECATED_SINCE(5, 65)
     emit done(d->checker->text());
+#endif
+    emit spellCheckDone(d->checker->text());
     emit spellCheckStatus(tr("Spell check stopped."));
     accept();
 }
@@ -272,18 +258,19 @@ void Dialog::setBuffer(const QString &buf)
 
 void Dialog::fillDictionaryComboBox()
 {
+    // Since m_language is changed to DictionaryComboBox most code here is gone,
+    // So fillDictionaryComboBox() could be removed and code moved to initGui()
+    // because the call in show() looks obsolete
     Speller speller = d->checker->speller();
     d->dictsMap = speller.availableDictionaries();
-    QStringList langs = d->dictsMap.keys();
-    d->ui.m_language->clear();
-    d->ui.m_language->addItems(langs);
+
     updateDictionaryComboBox();
 }
 
 void Dialog::updateDictionaryComboBox()
 {
     const Speller &speller = d->checker->speller();
-    d->ui.m_language->setCurrentIndex(d->dictsMap.values().indexOf(speller.language()));
+    d->ui.m_language->setCurrentByDictionary(speller.language());
 }
 
 void Dialog::updateDialog(const QString &word)
@@ -367,14 +354,13 @@ void Dialog::slotSkipAll()
 
 void Dialog::slotSuggest()
 {
-    QStringList suggs = d->checker->suggest(d->ui.m_replacement->text());
+    const QStringList suggs = d->checker->suggest(d->ui.m_replacement->text());
     fillSuggestions(suggs);
 }
 
 void Dialog::slotChangeLanguage(const QString &lang)
 {
-    Speller speller = d->checker->speller();
-    QString languageCode = d->dictsMap[lang];
+    const QString languageCode = d->dictsMap[lang];
     if (!languageCode.isEmpty()) {
         d->checker->changeLanguage(languageCode);
         slotSuggest();
@@ -404,8 +390,8 @@ void Dialog::slotMisspelling(const QString &word, int start)
         return;
     }
 
-    d->currentWord =  word;
-    d->currentPosition =  start;
+    d->currentWord = word;
+    d->currentPosition = start;
     if (d->replaceAllMap.contains(word)) {
         d->ui.m_replacement->setText(d->replaceAllMap[ word ]);
         slotReplaceWord();
@@ -418,7 +404,10 @@ void Dialog::slotMisspelling(const QString &word, int start)
 void Dialog::slotDone()
 {
     d->restart = false;
+#if SONNETUI_BUILD_DEPRECATED_SINCE(5, 65)
     emit done(d->checker->text());
+#endif
+    emit spellCheckDone(d->checker->text());
     if (d->restart) {
         updateDictionaryComboBox();
         d->checker->setText(d->originalBuffer);
@@ -428,10 +417,9 @@ void Dialog::slotDone()
         emit spellCheckStatus(tr("Spell check complete."));
         accept();
         if (!d->canceled && d->showCompletionMessageBox) {
-            QMessageBox::information(this, tr("Spell check complete."), tr("Check Spelling", "@title:window"));
+            QMessageBox::information(this, tr("Spell check complete."),
+                                     tr("Check Spelling", "@title:window"));
         }
     }
 }
-
 }
-
