@@ -1,29 +1,16 @@
 /*
  * highlighter.h
  *
- * Copyright (C)  2004  Zack Rusin <zack@kde.org>
- * Copyright (C)  2013  Martin Sandsmark <martin.sandsmark@kde.org>
+ * SPDX-FileCopyrightText: 2004 Zack Rusin <zack@kde.org>
+ * SPDX-FileCopyrightText: 2013 Martin Sandsmark <martin.sandsmark@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #ifndef SONNET_HIGHLIGHTER_H
 #define SONNET_HIGHLIGHTER_H
 
 #include <QSyntaxHighlighter>
-#include <QtCore/QStringList>
+#include <QStringList>
 #include "sonnetui_export.h"
 
 class QTextEdit;
@@ -45,7 +32,7 @@ public:
      * @since 5.12
      */
     explicit Highlighter(QPlainTextEdit *textEdit, const QColor &col = QColor());
-    ~Highlighter();
+    ~Highlighter() override;
 
     /**
      * Returns whether a spell checking backend with support for the
@@ -189,11 +176,11 @@ Q_SIGNALS:
     void activeChanged(const QString &description);
 
 protected:
-    void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
+    void highlightBlock(const QString &text) override;
     virtual void setMisspelled(int start, int count);
     virtual void unsetMisspelled(int start, int count);
 
-    bool eventFilter(QObject *o, QEvent *e) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *o, QEvent *e) override;
     bool intraWordEditing() const;
     void setIntraWordEditing(bool editing);
 
